import { getAllRoleList } from '@/api/system/role/role';
import { BasicColumn, FormSchema } from '@/components/Table';
import { h } from 'vue';
import { Switch } from 'ant-design-vue';
import { useMessage } from '@/hooks/web/useMessage';
import { changeFlagApi } from '@/api/system/user/user';
// 引入开关组件
type CheckedType = boolean | string | number;

/** 列表筛选项*/
export const searchFormSchema: FormSchema[] = [
  {
    field: 'fieldCode',
    label: ' ',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '请输入字段code进行搜索',
    },
  },
  {
    field: 'APIName',
    label: ' ',
    component: 'Input',
    colProps: { span: 4 },
    componentProps: {
      placeholder: '输入API名称进行搜索',
    },
  },
  {
    field: 'APIModel',
    label: ' ',
    component: 'Select',
    colProps: { span: 2 },
    componentProps: {
      placeholder: 'API模式',
      options: [
        { label: 'SQL模式', value: 'SQL模式' },
        { label: '托管模式', value: '托管模式' },
        { label: '向导模式', value: '向导模式' },
      ],
    },
  },
  {
    field: 'sensitiveState',
    label: ' ',
    component: 'Select',
    colProps: { span: 2 },
    componentProps: {
      placeholder: '敏感状态',
      options: [
        { label: '敏感', value: '敏感' },
        { label: '非敏感', value: '非敏感' },
      ],
    },
  },
  {
    field: 'level',
    label: ' ',
    component: 'Select',
    colProps: { span: 2 },
    componentProps: {
      placeholder: '安全分级',
      options: [
        { label: 'G1', value: 'G1' },
        { label: 'G2', value: 'G2' },
        { label: 'G3', value: 'G3' },
        { label: 'G4', value: 'G4' },
        { label: 'G5', value: 'G5' },
      ],
    },
  },
  {
    field: 'sensitiveType',
    label: ' ',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '敏感类型',
      options: [
        { label: '钱包类型', value: '钱包类型' },
        { label: 'AccessKey ID', value: 'AccessKey ID' },
        { label: '担保方式', value: '担保方式' },
      ],
    },
  },
];

/** 列表展示字段*/
export const columns: BasicColumn[] = [
  {
    title: '字段名',
    dataIndex: 'fieldName',
    width: 120,
  },
  {
    title: '字段类型',
    dataIndex: 'fieldType',
    width: 120,
  },
  {
    title: '字段code',
    dataIndex: 'fieldCode',
    width: 120,
  },
  {
    title: 'API名称',
    dataIndex: 'APIName',
    width: 140,
  },
  {
    title: '路径',
    dataIndex: 'path',
    width: 140,
  },
  {
    title: 'API模式',
    dataIndex: 'APIModel',
    width: 140,
  },
  {
    title: '敏感状态',
    dataIndex: 'sensitiveState',
    width: 180,
  },
  {
    title: '安全分级',
    dataIndex: 'level',
    width: 180,
  },
  {
    title: '敏感类型',
    dataIndex: 'sensitiveType',
    width: 180,
  },
  {
    title: '来源',
    dataIndex: 'source',
    width: 180,
  },
  {
    title: '标记时间',
    dataIndex: 'markTime',
    width: 180,
  },
];

/** 新增编辑表单字段*/
export const formSchema: any[] = [
  {
    field: 'sensitiveState',
    label: '敏感状态',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '敏感状态',
      options: [
        { label: '敏感', value: '敏感' },
        { label: '非敏感', value: '非敏感' },
      ],
    },
    rules: [
      {
        required: true,
        message: '请选择敏感状态',
      },
    ],
  },
  {
    field: 'sensitiveType',
    label: '敏感类型',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '敏感类型',
      options: [
        { label: '钱包类型', value: '钱包类型' },
        { label: 'AccessKey ID', value: 'AccessKey ID' },
        { label: '担保方式', value: '担保方式' },
      ],
    },
    dynamicRules: ({ values }) => {
      return values.flag === '敏感' ? [{ required: true, message: '说明必填' }] : [];
    },
  },

  {
    field: 'level',
    label: '安全分级',
    component: 'Select',
    colProps: { span: 3 },
    componentProps: {
      placeholder: '安全分级',
      options: [
        { label: 'G1', value: 'G1' },
        { label: 'G2', value: 'G2' },
        { label: 'G3', value: 'G3' },
        { label: 'G4', value: 'G4' },
        { label: 'G5', value: 'G5' },
      ],
    },
    dynamicRules: ({ values }) => {
      return values.flag === '敏感' ? [{ required: true, message: '说明必填' }] : [];
    },
  },
  {
    field: 'markTime',
    label: '标记时间',
    component: 'Input',
    componentProps: {
      allowClear: false,
      style: {
        border: 'none',
        backgroundColor: 'transparent',
      },
      readOnly: true,
    },
  },
];
